// Desc: A sample menu array structure definition, for use by PopupMenu.sqf.
// Concept By: Dr Eyeball
// Version: 1.1 (May 2007)
//-----------------------------------------------------------------------------
// Notes: Avoid using "format" command inside a caption, Item or Action string, since PopUpMenu will call PUM3_ReplaceCommonParams for parameter substitution.
//-----------------------------------------------------------------------------
private ["_MapClickPos", "_MapClickUnits", "_MapClickShift", "_MapClickAlt"];

//-----------------------------------------------------------------------------
// Get MapClick params
_MapClickParams = ["MapClickParams", _this, []] call fn_GetParamByName;

_MapClickPos = ["Pos", _MapClickParams, [0,0,0]] call fn_GetParamByName;
_MapClickUnits = ["Units", _MapClickParams, []] call fn_GetParamByName;
_MapClickShift = ["Shift", _MapClickParams, false] call fn_GetParamByName;
_MapClickAlt = ["Alt", _MapClickParams, false] call fn_GetParamByName;
//-----------------------------------------------------------------------------
// Get Action menu params
_ActionParams = ["ActionParams", _this, []] call fn_GetParamByName;

_ActionUnit = ["Unit", _ActionParams, objNull] call fn_GetParamByName;
_ActionCaller = ["Caller", _ActionParams, objNull] call fn_GetParamByName;
_ActionID = ["ID", _ActionParams, -1] call fn_GetParamByName;
_ActionParams = ["Params", _ActionParams, []] call fn_GetParamByName;
//-----------------------------------------------------------------------------
// Determine "Enabled" status of several menu items
_InAVehicle = [vehicle player] call fn_IsVehicle;

_pos = LCS9_CurrentTransportRequest select 0;
_RequestPickUpEnabled = format['%1', _pos] == '[0,0,0]';
_CancelRequestPickUpEnabled = format['%1', _pos] != '[0,0,0]';
_MapClickEnabled = (count _MapClickParams > 0) && (count _MapClickPos > 0) && (format["%1", _MapClickPos] != "[0,0,0]");

_HumanPlayersCount = 0; { if (IsPlayer _x) then { _HumanPlayersCount = _HumanPlayersCount + 1 }; } forEach units player;
_IsGroupLeader = (local player) && (leader player == player);
_GroupLeaderEnabled = _IsGroupLeader && (count units player > 1);
_HumanGroupLeaderEnabled = _IsGroupLeader && (count units player > 1) && (_HumanPlayersCount > 1);
//-----------------------------------------------------------------------------
// Create player list

// TODO: Fill array with real player list
PlayerList_MenuArray = 
[
  [ ["Item", "Dr Eyeball"], 
    ["Action", "player globalChat 'type: #vote admin [TOG] Dr Eyeball'"]
  ],
  [ ["Item", "The Terminator"], 
    ["Action", ""]
  ],
  [ ["Item", "Prince Charles"], 
    ["Action", ""]
  ],
  [ ["Item", "Mr Munchkin"], 
    ["Action", ""] 
  ]
];
//-----------------------------------------------------------------------------
// create TeamStatusAction - auto detect vehicle
_TeamStatusAction = "[0,player,0,['Group']] execVM 'TeamStatusDialog\TeamStatusDialog.sqf'";
//player sidechat format["ActionUnit=%1,%2", _ActionUnit, vehicleVarName _ActionUnit]; // debug
if (count _ActionParams > 0 && [_ActionUnit] call fn_IsVehicle) then
{
  // Requires Team Status Dialog v1.1
  _TeamStatusAction = format["[0,player,0,[['VehicleObject', '%1'], 'Vehicle']] execVM 'TeamStatusDialog\TeamStatusDialog.sqf'", _ActionUnit];
};
//-----------------------------------------------------------------------------
// Set "WP" enabled states
_Fake_CurrentWaypointId = 0;

_HasCurrentWaypoint = (_Fake_CurrentWaypointId > 0);

_WP1Exists = (count waypoints player > 1);
_WP2Exists = (count waypoints player > 2);
_WP3Exists = (count waypoints player > 3);
_WP4Exists = (count waypoints player > 4);
_WP5Exists = (count waypoints player > 5);
_WP6Exists = (count waypoints player > 6);
//-----------------------------------------------------------------------------
// Create "acknowledge pick-up" list

PickUpList_MenuArray = 
[
  // Sample only - script code removed
  [ ["Item", "ack, byWho, time, [pos]->[pos2], playerName, vehicle, purpose"], 
    ["Action", ""]
  ]
];
PickUpWaypointList_MenuArray = 
[
  // Sample only - script code removed
  [ ["Item", "Add pick-up waypoint ID x8: playerName, [pos]->[pos2]"], 
    ["Action", "nul=[1, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], 
    ["Enabled", true ] 
  ]
];

// script code removed
// ...

if (count PickUpList_MenuArray == 0) then
{
  PickUpList_MenuArray = 
  [
    [ ["Item", "None"], 
      ["Action", ""],
      ["Enabled", false]
    ]
  ];
};
if (count PickUpWaypointList_MenuArray == 0) then
{
  PickUpWaypointList_MenuArray =
    [
      [ ["Item", "None"], 
        ["Action", ""],
        ["Enabled", false]
      ]
    ];
};

//player sideChat format["%1", PickUpList_MenuArray]; // debug
//player sideChat format["%1", G_LCS9_TransportRequests]; // debug
//-----------------------------------------------------------------------------
_MenuStructureArray =
[
  //_MapClickParams,
  ["MapClickParams",
    [
      ["Pos", _MapClickPos],
      ["Units",_MapClickUnits],
      ["Shift", _MapClickShift],
      ["Alt", _MapClickAlt]
    ]
  ],
  
  //_ActionParams,
  
  ["MainMenu",
    [
      ["Caption", "Logistics Control System"],
      ["Items",
        [
          [ ["Item", "Waypoints >"], ["SubMenu", "Waypoints"] ],
          [ ["Item", "Transport >"], ["SubMenu", "Transport"] ],
          [ ["Item", "HQ support >"], ["SubMenu", "HQ"] ],
          //[ ["Item", "Request Support >"], ["SubMenu", "Support"] ],
          //[ ["Item", "Set objectives >"], ["SubMenu", "Objectives"] ],
          //[ ["Item", "Squad comm's >"], ["SubMenu", "SquadComms"] ],
          //[ ["Item", "Voting commands >"], ["SubMenu", "Voting"] ]
          [ ["Item", "Team status..."], ["Action", _TeamStatusAction] ],
          [ ["Item", "-"] ],
          [ ["Item", "Configuration >"], ["SubMenu", "Configuration"] ],
          [ ["Item", "Close Menu"],
            ["Close", true],
            ["Default", true]
          ]
        ]
      ]
    ]
  ],

  ["Configuration",
    [
      ["Caption", "Configuration"],
      ["Items",
        [
          [ ["Item", "Map - Use backpack"], ["Action", "nul=execVM 'Scripts\ConfigMenu\ToggleHideNotepad.sqf'"] ],
          [ ["Item", "Set view distance >"], ["SubMenu", "ViewDistance"] ],
          //[ ["Item", "Set flying view distance >"], ["SubMenu", "FlyingViewDistance"] ],
          [ ["Item", "Set terrain detail >"], ["SubMenu", "TerrainDetail"] ]
        ]        
      ]
    ]
  ],

  ["ViewDistance",
    [
      ["Caption", "View Distance"], // "[Current: ####m]"
      ["Items",
        [
          [ ["Item", "Close Menu"],
            ["Close", true],
            ["Default", true]
          ],
          [ ["Item", "-"] ],
          [ ["Item", "600m"], ["Action", "setViewDistance 600"], ["Close", false] ],
          [ ["Item", "800m"], ["Action", "setViewDistance 800"], ["Close", false] ],
          [ ["Item", "1000m"], ["Action", "setViewDistance 1000"], ["Close", false] ],
          [ ["Item", "1200m"], ["Action", "setViewDistance 1200"], ["Close", false] ],
          [ ["Item", "1500m"], ["Action", "setViewDistance 1500"], ["Close", false] ],
          [ ["Item", "1800m"], ["Action", "setViewDistance 1800"], ["Close", false] ],
          [ ["Item", "2100m"], ["Action", "setViewDistance 2100"], ["Close", false] ],
          [ ["Item", "2500m"], ["Action", "setViewDistance 2500"], ["Close", false] ],
          [ ["Item", "5000m"], ["Action", "setViewDistance 5000"], ["Close", false] ],
          // increase/decrease requires tracking a ViewDistance variable. See BAS f
          [ ["Item", "Decrease by 100m"], ["Action", "hint 'not implemented'"], ["Close", false] ],
          [ ["Item", "Increase by 100m"], ["Action", "hint 'not implemented'"], ["Close", false] ]
        ]
      ]
    ]
  ],

  ["FlyingViewDistance",
    [
      ["Caption", "Flying View Distance"], // "[Current: ####m]"
      ["Items",
        [
          // temp fake code: need "GetIn" event handler for this. See BAS f
          [ ["Item", "Close Menu"],
            ["Close", true],
            ["Default", true]
          ],
          [ ["Item", "-"] ],
          [ ["Item", "600m"], ["Action", "setViewDistance 600"], ["Close", false] ],
          [ ["Item", "800m"], ["Action", "setViewDistance 800"], ["Close", false] ],
          [ ["Item", "1000m"], ["Action", "setViewDistance 1000"], ["Close", false] ],
          [ ["Item", "1200m"], ["Action", "setViewDistance 1200"], ["Close", false] ],
          [ ["Item", "1500m"], ["Action", "setViewDistance 1500"], ["Close", false] ],
          [ ["Item", "1800m"], ["Action", "setViewDistance 1800"], ["Close", false] ],
          [ ["Item", "2100m"], ["Action", "setViewDistance 2100"], ["Close", false] ],
          [ ["Item", "2500m"], ["Action", "setViewDistance 2500"], ["Close", false] ],
          [ ["Item", "5000m"], ["Action", "setViewDistance 5000"], ["Close", false] ],
          [ ["Item", "Decrease by 100m"], ["Action", "hint 'not implemented'"], ["Close", false] ],
          [ ["Item", "Increase by 100m"], ["Action", "hint 'not implemented'"], ["Close", false] ]
        ]
      ]
    ]
  ],

  ["TerrainDetail",
    [
      ["Caption", "Terrain Detail"],
      ["Items",
        [
          [ ["Item", "Close Menu"],
            ["Close", true],
            ["Default", true]
          ],
          [ ["Item", "-"] ],
          [ ["Item", "Low - smoothest, least lag"],
            ["Action", "setTerrainGrid 50; hint 'Terrain Detail set to Low'"],
            ["Close", false]
          ],
          [ ["Item", "Medium - default in multiplayer"],
            ["Action", "setTerrainGrid 25; hint 'Terrain Detail set to Medium'"],
            ["Close", false]
          ],
          [ ["Item", "High - default in singleplayer"],
            ["Action", "setTerrainGrid 12.5; hint 'Terrain Detail set to High'"],
            ["Close", false]
          ],
          [ ["Item", "Very High"],
            ["Action", "setTerrainGrid 6.25; hint 'Terrain Detail set to Very High'"],
            ["Close", false]
          ],
          [ ["Item", "Ultra High - bumpiest, highest lag"],
            ["Action", "setTerrainGrid 3.125; hint 'Terrain Detail set to Ultra High'"],
            ["Close", false]
          ]
        ]
      ]
    ]
  ],

  /*  
  ["Voting",
    [
      ["Caption", "Voting"],
      ["Items",
        [
          [ ["Item", "User List"], 
            ["Action", "player groupChat 'type: #userlist'"]
          ],
          [ ["Item", "Vote kick against player >"], 
            ["SubMenu", "PlayerList"],
            ["UserList", true]
          ],
          [ ["Item", "Vote user as Admin >"], 
            ["SubMenu", "PlayerList"],
            ["UserList", true]
          ]
        ]
      ]
    ]
  ],
  */
  
  /* Utilise existing ArmA menus for support for now. Would like to replace them with smarter support though without the need for a "Done" command.
  ["Support",
    [
      ["Caption", "Request Support"],
      ["Items",
        [
          [ ["Item", "Requesting [ammoType] ammo at [my location]"], 
            ["Action", ""] 
          ],
          [ ["Item", "Requesting vehicle rearm truck at [my location]"], 
            ["Action", ""] 
          ],
          [ ["Item", "Requesting repair truck at [my location]"], 
            ["Action", ""] 
          ],
          [ ["Item", "Requesting fuel truck at [my location]"], 
            ["Action", ""] 
          ],
          [ ["Item", "Requesting medic at [my location]"], 
            ["Action", ""] 
          ]
        ]
      ]
    ]
  ],
  */
  
  ["HQ",
    [
      ["Caption", "Request HQ Command Support"],
      ["Items",
        [
          [ ["Item", "Recruit a soldier >"], ["SubMenu", "SpawnAI"] ],
          //[ ["Item", "Request paratrooper reenforcements at [%4]"], ["Action", ""], ["Enabled", _IsGroupLeader] ], // AI plane para drop some AI.
          //[ ["Item", "Request infantry reenforcements by chopper at [%4]"], ["Action", ""], ["Enabled", _IsGroupLeader] ], // AI chopper drop off some AI
          //[ ["Item", "Request artillery at [my mark]"], ["Action", ""], ["Enabled", _GroupLeaderEnabled] ],
          //[ ["Item", "Setting jet target at [my mark]"], ["Action", ""] ],
          //[ ["Item", "Request UAV intel"], ["Action", ""], ["Enabled", _IsGroupLeader] ],
          //[ ["Item", "Spotted [unitType] at [Pos] heading [Dir]"], ["Action", ""] ],
          //[ ["Item", "Request support against [unitType]"], ["Action", ""] ],
          [ ["Item", "Request air-drop >"], ["SubMenu", "AirDrop"] ]
        ]
      ]
    ]
  ],
  
  ["SpawnAI",
    [
      ["Caption", "Recruit a Soldier"],
      ["Items",
        [
          [ ["Item", "AA"], ["Action", "nul=['SoldierWAA'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "AT"], ["Action", "nul=['SoldierWAT'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Auto Rifleman"], ["Action", "nul=['SoldierWAR'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Camel Pilot"], ["Action", "nul=['BISCamelPilot'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Crewman"], ["Action", "nul=['SoldierWCrew'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Engineer"], ["Action", "nul=['SoldierWMiner'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Grenadier"], ["Action", "nul=['SoldierWG'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "MG"], ["Action", "nul=['SoldierWMG'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Medic"], ["Action", "nul=['SoldierWMedic'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Officer"], ["Action", "nul=['OfficerW'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Pilot"], ["Action", "nul=['SoldierWPilot'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Rifleman"], ["Action", "nul=['SoldierWB'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SF Assault"], ["Action", "nul=['SoldierWSaboteurAssault'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SF Marksman"], ["Action", "nul=['SoldierWSaboteurMarksman'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SF Recon"], ["Action", "nul=['SoldierWSaboteurRecon'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SF Saboteur"], ["Action", "nul=['SoldierWSaboteur'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SF Saboteur Pipe"], ["Action", "nul=['SoldierWSaboteurPipe'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "Sniper"], ["Action", "nul=['SoldierWSniper'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "SL"], ["Action", "nul=['SquadLeaderW'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ],
          [ ["Item", "TL"], ["Action", "nul=['TeamLeaderW'] execVM 'Scripts\LCS\RecruitAI.sqf'"], ["Enabled", _IsLeader] ]
        ]
      ]
    ]
  ],
  
  ["AirDrop",
    [
      ["Caption", "Request Air-Drop Support"],
      ["Items",
        [
          [ ["Item", "Request ammo crate at [%6]"],
            ["Action", "nul=[player,'SpecialBoxWest',%5] execVM 'Scripts\LCS\ParadropSendAircraft.sqf'"],
            ["Enabled", _IsGroupLeader]
          ],
          [ ["Item", "Requesting Landrover drop at [%6]"], 
            ["Action", "nul=[player,'Landrover',%5] execVM 'Scripts\LCS\ParadropSendAircraft.sqf'"],
            ["Enabled", _IsGroupLeader]
          ],
          [ ["Item", "Requesting PBX drop at [%6]"], 
            ["Action", "nul=[player,'PBX',%5] execVM 'Scripts\LCS\ParadropSendAircraft.sqf'"],
            ["Enabled", _IsGroupLeader]
          ],
          [ ["Item", "Request air drop progress report"], 
            ["Action", "nul=[] execVM 'Scripts\LCS\ParadropStatus.sqf'"],
            ["Close", false]
          ]
        ]
      ]
    ]
  ],
  
  ["Transport",
    [
      ["Caption", "Request Transport to [%8]"],
      ["Items",
        [
          [ ["Item", "Acknowledge pick-up request >"], 
            ["SubMenu", "PickUpList"]
          ],
          [ ["Item", "-"] // separator
          ], 
          [ ["Item", "Cancel transport request"],
            ["Action", "nul=[[vehicle player, 'seat', player], ['manual cancel']] execVM 'Scripts\LCS\RequestTransportCancel.sqf'"],
            ["Enabled", _CancelRequestPickUpEnabled ]
          ],
          [ ["Item", "-"] // separator
          ], 
          /*[ ["Item", "Request MedEvac at [%4]"], 
            ["Action", "" ]
          ],
          [ ["Item", "Request a stranded sea pick-up at [position]"], 
            ["Action", ""] 
          ],*/
          [ ["Item", "Request chopper pick-up"], 
            ["Action", "nul=[%1, %7, 'field', 'chopper'] execVM 'Scripts\LCS\RequestTransport.sqf'"],
            ["Enabled", _RequestPickUpEnabled ]
          ],
          [ ["Item", "Request any pick-up"], 
            ["Action", "nul=[%1, %7, 'field', 'any vehicle'] execVM 'Scripts\LCS\RequestTransport.sqf'"],
            ["Enabled", _RequestPickUpEnabled ]
          ],
          [ ["Item", "-"] // separator
          ], 
          [ ["Item", "Set Landing Zone (map)"], 
            ["Action", "nul=[player, %3, '%4'] execVM 'Scripts\LCS\SetLZ.sqf'"],
            ["Enabled", _MapClickEnabled]
          ],
          [ ["Item", "Request A.I. chopper deployment (to my LZ)"],
            ["Action", ""],
            ["Enabled", format["%1", LCS9_LZPosition] != "[0,0,0]" && typeName LCS9_LZPosition == "ARRAY"]
          ]/*,
          [ ["Item", "-"] // separator
          ], 
          [ ["Item", "Request chopper base deployment"], 
            ["Action", "nul=[%1, %7, 'deployment', 'chopper'] execVM 'Scripts\LCS\RequestTransport.sqf'"],
            ["Enabled", _RequestPickUpEnabled ]
          ],
          [ ["Item", "Request general base deployment"], 
            ["Action", "nul=[%1, %7, 'field', 'any vehicle'] execVM 'Scripts\LCS\RequestTransport.sqf'"],
            ["Enabled", _RequestPickUpEnabled ]
          ],
          [ ["Item", "Request return to base transport"], 
            ["Action", "nul=[%1, %7, 'RTB', 'any vehicle'] execVM 'Scripts\LCS\RequestTransport.sqf'"],
            ["Enabled", _RequestPickUpEnabled ]
          ]*/
        ]
      ]
    ]
  ],
  
  ["PickUpList",
    [
      ["Caption", "Active pick-up requests"],
      ["Items", PickUpList_MenuArray]
    ]
  ],
  
  /* basically you can use the waypoint purpose command instead
  ["Objectives",
    [
      ["Caption", "Set Objectives"],
      ["Items",
        [
          [ ["Item", "Destroy this object"], ["Action", ""] ],
          [ ["Item", "Move to primary objective 1 >"], ["Action", ""] ],
          [ ["Item", "Move to secondary objective 1 >"], ["Action", ""] ],
          [ ["Item", "Move to primary objective 2 >"], ["Action", ""] ],
          [ ["Item", "Move to secondary objective 2 >"], ["Action", ""] ],
          [ ["Item", "Move to primary objective 3 >"], ["Action", ""] ],
          [ ["Item", "Move to secondary objective 3 >"], ["Action", ""] ]
        ]
      ]
    ]
  ],
  */
  
  ["Waypoints",
    [
      ["Caption", "Waypoints"],
      ["Items",
        [
          [ ["Item", "Set waypoint (via Map) >"],
            ["SubMenu", "SetWaypoint"]
          ],
          [ ["Item", "Add transport request waypoint >"],
            ["SubMenu", "TransportWaypoints"]
          ],
          [ ["Item", "-"]
          ],
          [ ["Item", format["Switch current waypoint: [%1] >", _Fake_CurrentWaypointId]],
            ["SubMenu", "SwitchWaypoint"],
            ["Enabled", _IsGroupLeader && _WP1Exists]
          ],
          [ ["Item", format["Set current waypoint purpose: %1 >", _Fake_CurrentWaypointId]], 
            ["SubMenu", "SetWaypointPurpose"],
            ["Enabled", _WP1Exists]
          ],
          [ ["Item", "-"]
          ],
          [ ["Item", format["Delete current waypoint: %1", _Fake_CurrentWaypointId]], 
            ["Action", "deleteWaypoint [group player, _Fake_CurrentWaypointId]; _Fake_CurrentWaypointId = 0; hint 'Current waypoint deleted'"],
            ["Enabled", _IsGroupLeader && _WP1Exists && _HasCurrentWaypoint]
          ],
          [ ["Item", format["Clear all waypoints (%1)", 0 max (count waypoints player)-1]], 
            ["Action", "while { count waypoints player > 1 } do { deleteWaypoint [group player, 1] }; _Fake_CurrentWaypointId = 0; hint 'Waypoints cleared';"],
            ["Enabled", _IsGroupLeader && _WP1Exists]
          ]
        ]
      ]
    ]
  ],

  ["SetWaypoint",
    [
      ["Caption", "Set waypoint [%4] (Click Map)"],
      ["Items",
        [
          [ ["Item", "Set waypoint 1"], ["Action", "nul=[1, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", true ] ],
          [ ["Item", "Set waypoint 2"], ["Action", "nul=[2, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", _WP1Exists ] ],
          [ ["Item", "Set waypoint 3"], ["Action", "nul=[3, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", _WP2Exists ] ],
          [ ["Item", "Set waypoint 4"], ["Action", "nul=[4, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", _WP3Exists ] ],
          [ ["Item", "Set waypoint 5"], ["Action", "nul=[5, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", _WP4Exists ] ],
          [ ["Item", "Set waypoint 6"], ["Action", "nul=[6, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", _WP5Exists ] ]
        ]
      ]
    ]
  ],

  ["TransportWaypoints",
    [
      ["Caption", "Add Transport Waypoint"],
      ["Items", PickUpWaypointList_MenuArray]
      /*
        [
          [ ["Item", "Add pick-up waypoint ID x8"], ["Action", "nul=[1, %3] execVM 'Scripts\LCS\SetWaypoint.sqf'" ], ["Enabled", true ] ]
        ]        
      */
    ]
  ],
  
  ["SwitchWaypoint",
    [
      ["Caption", "Switch current waypoint"],
      ["Items",
        [
          [ ["Item", "Waypoint 1"], ["Action", "nul=[1] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP1Exists ] ],
          [ ["Item", "Waypoint 2"], ["Action", "nul=[2] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP2Exists ] ],
          [ ["Item", "Waypoint 3"], ["Action", "nul=[3] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP3Exists ] ],
          [ ["Item", "Waypoint 4"], ["Action", "nul=[4] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP4Exists ] ],
          [ ["Item", "Waypoint 5"], ["Action", "nul=[5] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP5Exists ] ],
          [ ["Item", "Waypoint 6"], ["Action", "nul=[6] execVM 'Scripts\LCS\SwitchWaypoint.sqf'"], ["Enabled", _WP6Exists ] ]
        ]
      ]
    ]
  ],

  ["SetWaypointPurpose",
    [
      ["Caption", "Switch current waypoint"],
      ["Items",
        [
          [ ["Item", "Move"], ["Action", "nul=['Move'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Attack"], ["Action", "nul=['Attack'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Wait/Meet here"], ["Action", "nul=['Wait'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Destroy"], ["Action", "nul=['Destroy'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Defend"], ["Action", "nul=['Defend'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Primary Objective"], ["Action", "nul=['Primary Objective'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Secondary Objective"], ["Action", "nul=['Secondary Objective'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Landing Zone"], ["Action", "nul=['LZ'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ],
          [ ["Item", "Air Drop"], ["Action", "nul=['Air Drop'] execVM 'Scripts\LCS\SetWaypointPurpose.sqf'"] ]
        ]
      ]
    ]
  ],

  /*
  ["SquadComms",
    [
      ["Caption", "Squad Comm's"],
      ["Items",
        [
          //[ ["Item", "Request Orders >"], ["Action", "player groupChat 'Requesting new orders.'"] ],
          [ ["Item", "Request orders from leader"], ["Action", "player groupChat 'Requesting new orders.'"], ["Enabled", !_IsGroupLeader] ],
          [ ["Item", "Report position to team"], 
            ["Action", "player sideChat format['My position is %2']"] ],
          [ ["Item", "Report status to team"], 
            ["Action", "player sideChat format['"+
              "My position is %2. Injuries: [None]. Vehicle damage: [Low]. Ammo: [Low]. Status: [Engaging].']"] ]
          //[ ["Item", "Taking fire!"], ["Action", "player groupChat 'Taking fire!'"] ],
          //[ ["Item", "Under heavy fire!"], ["Action", "player groupChat 'Under heavy fire!'"] ],
          //[ ["Item", "Thanks man!"], ["Action", "player sideChat 'Thanks man!'"] ]
        ]
      ]
    ]
  ],
  */

  ["PlayerList",
    [
      ["Caption", "Player List"],
      ["Items", PlayerList_MenuArray]
    ]
  ]
  
];

//["CreatePopupMenu.sqf", _MenuStructureArray] call fn_DebugAppend; // debug
nul=_MenuStructureArray execVM "Dialogs\Common\PopupMenu.sqf";
//-----------------------------------------------------------------------------
